# =============================================================================
# Imports
# =============================================================================
# Python Imports
from __future__ import with_statement
import random

# EventScripts Imports
import es


# =============================================================================
#   LIBRARY INFORMATION
# =============================================================================
info = es.AddonInfo()
info.name = "Random Bot Names"
info.version = "Version 1"
info.url = "http://addons.eventscripts.com/addons/view/random_bot_names"
info.basename = "random_bot_names"
info.author = "XE_ManUp"


# =============================================================================
# Global Variables
# =============================================================================
bot_names = None
used_names = []


# =============================================================================
# Helper Functions
# =============================================================================
def generate_bot_names():
    """Retrieves the bot names from the names.txt file."""
    global bot_names
    with open('%s/names.txt' % es.getAddonPath('random_bot_names'), 'r') as f:
        bot_names = [x.strip() for x in f.readlines() if x.strip() and \
                     not x.strip().startswith('//')]


def check_available_names():
    """Checks if any names are still available, or if they have all been
    used.

    """
    return list(set(bot_names).difference(used_names))


# =============================================================================
# Event Functions
# =============================================================================
def load():
    # Retrieve the bot names
    generate_bot_names()

    # If there are no bot names available, there is no sense in staying loaded
    if not bot_names:
        es.dbgmsg(0, 'Unloading random_bot_names: No bot names detected.')
        es.unload('random_bot_names')


def es_map_start(event_var):
    # Bots do not fire player_disconnect on map change - clear the used names
    del used_names[:]


def player_activate(event_var):
    userid = int(event_var['userid'])

    # If not a bot, return
    if not es.isbot(userid):
        return

    # If no available names, return
    if not check_available_names():
        return

    # Retrieve a random player name
    new_name = random.choice(list(set(bot_names).difference(used_names)))

    # Add the name to the used names list
    used_names.append(new_name)

    # Set the bot name
    es.botsetvalue(userid, 'name', new_name)


def player_disconnect(event_var):
    # If not a bot, return
    if not event_var['es_steamid'] == 'BOT':
        return

    # Retrieve the bot name
    name = event_var['es_username']

    # Remove the bot name from the used names list
    if name in used_names:
        used_names.remove(name)
